#[repr(i32)]pub enum CuckooHashAlgorithm {
SipHash = 0,
}Expand description
Hash algorithm for a CuckooFilter (on the wire for forward-compat).
Variants
SipHash = 0
Implementations
Sourceimpl CuckooHashAlgorithm
impl CuckooHashAlgorithm
Sourcepub fn from_i32(value: i32) -> Option<CuckooHashAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<CuckooHashAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a CuckooHashAlgorithm, or None if value is not a valid variant.
Sourceimpl CuckooHashAlgorithm
impl CuckooHashAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<CuckooHashAlgorithm>
pub fn from_str_name(value: &str) -> Option<CuckooHashAlgorithm>
Creates an enum from field names used in the ProtoBuf definition.